..
.. January 15 2018, Christian Hopps <chopps@gmail.com>
..

************
Installation
************

At the command line::

    $ pip install netconf

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv netconf
    $ pip install netconf
